setwd("/data/sPlot/users/Helge/HIDDEN")
library(tidyverse)
library(foreign)
library(gridExtra)
library(grid)

source("99_HIDDEN_functions.R")


#### 1. traits data  #### 

traits0 <- read_delim("_data/Mesobromion/traits3.txt", delim =";", col_names = T, locale = locale(encoding = 'latin1')) %>% 
  dplyr::select(- c("PR_STAT_Indigen", "PR_STAT_Neophyt", "PR_STAT_Archaeophyt", "URBAN_urbanophob", "URBAN_maessig_urbanophob", 
                    "URBAN_urbanoneutral", "URBAN_maessig_urbanophil", "URBAN_urbanophil", "WUH_von", "WUH_bis", "ARL_c_I_von", "ARL_c_I_bis")) %>% 
  mutate(species0=species) %>% 
  rowwise() %>% 
  # quick and dirty clean up names
  mutate(species=gsub(pattern="_", replacement = " ", x = species)) %>% 
  mutate(species=gsub(pattern=" agg | x | spec$| agg$| s | Sec |  ", replacement=" ", x=species)) %>% 
  mutate(species=gsub(pattern=" $", replacement = "", x = species)) %>% 
  mutate(species=ifelse(is.na(word(species, 1, 2)), species, word(species, 1, 2)))
dim(traits0) #907 obs. of  75 variables:



#keep only traits with >=88 completeness
traits0 <- traits0 %>% 
  dplyr::select_if(~mean(!is.na(.)) >= 0.88) # 907 x 67

### Transform binary traits to 0-1
traits.asym.binary <- c('LEB_F_Makrophanerophyt','LEB_F_Nanophanerophyt',
                        'LEB_F_Hemikryptophyt','LEB_F_Geophyt','LEB_F_Hemiphanerophyt','LEB_F_Therophyt',
                        'LEB_F_Hydrophyt','LEB_F_Pseudophanerophyt','LEB_F_Chamaephyt',
                        'LEB_D_plurienn_pollakanth','LBE_D_plurienn_hapaxanth','LEB_D_annuell',
                        'LEB_D_bienn','V_VER_absent','V_VER_Wurzelspross','V_VER_Ausläufer','
                        V_VER_Rhizom','V_VER_Innovationsknopse.mit.Wurzelknolle',
                        'V_VER_Innovationsknospe.mit.Speicherwurzel','V_VER_Ausläuferknolle',
                        'V_VER_Brutsprösschen','V_VER_Fragmentation','V_VER_Turio','V_VER_Sprossknolle',
                        'V_VER_phyllogener_Spross','V_VER_Rhizompleiokorm','V_VER_Zwiebel',
                        'V_VER_Ausläuferrhizom','V_VER_Ausläuferzwiebel','V_VER_Bulbille',
                        'ROS_T_rosettenlose.Pflanzen','ROS_T_Halbrosettenpflanze','ROS_T_Ganzrosettenpflanzen',
                        'BL_AUSD_immergrün','BL_AUSD_sommergrün','BL_AUSD_vorsommergrün',
                        'BL_AUSD_überwinternd_grün','BL_ANAT_skleromorph','BL_ANAT_mesomorph',
                        'BL_ANAT_hygromorph','BL_ANAT_hydromorph','BL_ANAT_blattsukkulent','BL_ANAT_helomorph',
                        'BL_FORM_gelappt_gefiedert_gefingert_mehrfach','BL_FORM_Vollblatt_Normalblatt',
                        'BL_FORM_Grasblatt_Langblatt','BL_FORM_nadelförmig','BL_FORM_röhrig',
                        'BL_FORM_schuppenförmig','BL_FORM_schwertförmig','REPR_T_Samen_Sporen',
                        'REPR_T_vegetativ','BLU_KL_WIND','BLU_KL_POLLEN',
                        'BLU_KL_NEKTAR_HONIG_INSEKTEN','STRAT_T_C','STRAT_T_CR','STRAT_T_CS',
                        'STRAT_T_CSR','STRAT_T_R','STRAT_T_S','STRAT_T_SR')

traits0 <- traits0 %>% 
  mutate_at(.vars=vars(any_of(traits.asym.binary)), 
            .funs=~(.>0)*1)


## Import traits from TRY and match to species
load("/data/sPlot2.0/TRY.all.mean.sd.3.by.genus.species.tree.Rdata")
alltry <- TRY.all.mean.sd.3.by.genus.species.tree %>% 
  dplyr::select(!ends_with(".sd")) %>% 
  dplyr::select(StandSpeciesName, LeafArea.mean:Wood.vessel.length.mean) %>% 
  dplyr::select(-Wood.vessel.length.mean, -StemDens.mean, -Stem.cond.dens.mean) %>% 
  rename_all(.funs=~gsub(pattern=".mean$", replacement="", x=.))

traits <- traits0 %>% 
  ungroup() %>% 
  #dplyr::select(species, species0) %>% 
  left_join(alltry %>% 
              rename(species=StandSpeciesName), 
            by="species") %>% 
  filter(!is.na(LeafArea))
dim(traits) #[1] 805  2



##### 2. Header Data #### 
env0 <- read_delim("_data/Mesobromion/GVRD_MES2_site.csv", delim = ",")
str(env0) #6868 obs. of  6 variables:

set.seed(1984)
header   <- "/data/sPlot/users/Francesco/Project_11/Germany/_data/tvhabita.dbf"
env  <- env0 %>% 
  left_join(foreign::read.dbf(header) %>% 
              as.data.frame() %>% 
              dplyr::select(RELEVE_NR, LAT, LON),
            by="RELEVE_NR") %>% 
  filter(!is.na(LAT)) %>%
  filter(!(LAT==0 | LON==0)) 



### 3. Import species data #### 
# columns in species correspond to those in env
# there is no PlotObservationID (yet)
species0 <- read.table("_data/Mesobromion/GVRD_Mes2_veg1.csv", sep = ",", header=T)
dim(species0) #6868 obs. of  907 variables:
rownames(species0) <- env0$RELEVE_NR

## select only plots already selected in env
species <- env %>% 
  dplyr::select(RELEVE_NR) %>% 
  left_join(species0 %>%
              mutate(RELEVE_NR=env0$RELEVE_NR), 
            by="RELEVE_NR") %>% 
  column_to_rownames("RELEVE_NR") %>% 
  ## delete species not appearing in any plot
  dplyr::select(colnames(.)[which(colSums(.)!=0)])
  #dplyr::select(traits$species0)

dim(species) # [1] 5810 881

releve08trait <- species %>% 
  rownames_to_column("RELEVE_NR") %>% 
  reshape2::melt(.id="RELEVE_NR") %>% 
  rename(species0=variable, pres=value) %>% 
  as.tbl() %>% 
  filter(pres>0) %>% 
  arrange(RELEVE_NR)  %>% 
  ## attach traits 
  left_join(traits %>% 
              dplyr::select(-species), by="species0") %>% 
  mutate_at(.vars = vars(LEB_F_Makrophanerophyt:Disp.unit.leng), 
            .funs = list(~if_else(is.na(.),0,1) * pres)) %>%
  group_by(RELEVE_NR) %>%
  summarize_at(.vars= vars(LEB_F_Makrophanerophyt:Disp.unit.leng),
               .funs = list(~mean(.))) %>%
  dplyr::select(RELEVE_NR, order(colnames(.))) %>%
  reshape2::melt(id.vars="RELEVE_NR", value.name="trait.coverage") %>% 
  group_by(RELEVE_NR) %>% 
  summarize(ntraits08=mean(trait.coverage>=0.8)) %>% 
  #select only those releves where we have a coverage of >0.8 for all traits
  filter(ntraits08==1) %>% 
  pull(RELEVE_NR)

set.seed(1984)
releve08trait.samp <- sample(releve08trait, round(length(releve08trait)/10), replace=F)
species <- species %>% 
  rownames_to_column("RELEVE_NR") %>% 
  filter(RELEVE_NR %in% releve08trait.samp) %>% 
  column_to_rownames("RELEVE_NR") %>% 
  as.tbl() %>% 
  dplyr::select(one_of(traits$species0))


env <- env %>% 
  filter(RELEVE_NR %in% releve08trait.samp)

traits <- traits %>% 
  dplyr::select(-species) %>% 
  dplyr::select(species0, everything()) %>% 
  filter(species0 %in% colnames(species))
  
dim(species) #558 783
dim(traits) #783 81
dim(env) #558 8


## Select only plots where >90% of species have trait info [TRY]
# releve08trait <- species %>% 
#   rownames_to_column("RELEVE_NR") %>% 
#   reshape2::melt(.id="RELEVE_NR") %>% 
#   rename(species0=variable, pres=value) %>% 
#   filter(pres>0) %>% 
#   arrange(RELEVE_NR)  %>% 
#   ## attach traits 
#   left_join(traits %>% 
#               dplyr::select(-species, LeafArea.mean), by="species0") %>% 
#   group_by(RELEVE_NR) %>% 
#   summarize(trait.coverage=mean(!is.na(LeafArea.mean))) %>% 
#   filter(trait.coverage<0.8) %>% 
#   pull(RELEVE_NR)
# 






##export for Valerio
write_delim(species, path="_data/Mesobromion/species.out.10perc.txt", delim="\t")
write_delim(traits, path="_data/Mesobromion/traits.out.10perc.txt", delim="\t")





#### CORRELATION BETWEEN FUZZY WEIGHTED AND BEALS MATRICES  #### #### #### 
#### WAS RUN IN THE CLUSTER WITH THE SCRIPT 01b_MesobromionCluster.R


#### ## Reimport data #### 
############################
## calculate corr between species composition matrix and traits
species <- read_delim("_data/Mesobromion/species.out.10perc.txt", delim="\t")
traits <- read_delim("_data/Mesobromion/traits.out.10perc.txt", delim="\t")

traits <- traits %>% 
  column_to_rownames("species0") # %>% 
  #dplyr::select(LeafArea:Disp.unit.leng)
  #dplyr::select(PlantHeight, LeafC.perdrymass, LeafN, StemDens, Stem.cond.dens, Seed.num.rep.unit, SLA)


#### ## Import output #### 
myfilelist <- list.files(path="_derived/Mesobromion/", pattern="HIDDEN_sign_[0-9]+.RData", full.names = T)
dataFiles = purrr::map(myfilelist, function(x){get(load(x))}) 
corXY = bind_rows(dataFiles) %>% 
  as.tbl()
rm( dataFiles)

trait.labs <- data.frame(Trait.comb=1:ncol(traits), 
                 trait.name=colnames(traits))#[-which(colnames(traits) %in% c("species", "species0"))])

## calculate confidence intervals for bootstrapped correlations
corXY.ci <- corXY %>% 
  filter(bootstr.n==0) %>% 
  dplyr::select(-bootstr.n) %>% 
  group_by(Trait.comb) %>% 
  slice(1) %>% 
  left_join(corXY %>% 
              filter(bootstr.n!=0) %>% 
              group_by(Trait.comb) %>% 
              summarize(q025=quantile(Coef.obs, 0.025),
                        q975=quantile(Coef.obs, 0.975),
                        greater.than.perm=mean(Coef.obs>Coef.perm), 
                        n=n())) %>% 
  #calculate significance using permuted correlations
  mutate(sign_plus=greater.than.perm>0.975) %>% 
  mutate(sign_minus=greater.than.perm<0.025)  %>% 
  mutate(Trait.comb2=Trait.comb) %>% 
  #split strings of trait combinations and add labels
  separate(Trait.comb2, into=paste0("trait", 1:15)) %>% 
  mutate_at(.vars=vars(trait1:trait15),
            .funs=~factor(., levels=trait.labs$Trait.comb, labels=trait.labs$trait.name)) %>% 
  rowwise() %>% 
  mutate(ntraits= length(unlist(strsplit(Trait.comb, "_")))) %>% 
  ungroup() %>% 
  arrange(ntraits, Coef.obs) %>% 
  dplyr::select(Trait.comb, Test, n, ntraits, everything()) %>% 
  mutate_at(.vars=vars(starts_with("sign")), 
            .funs=~factor(.*1, levels=c(0,1), labels=c("FALSE", "TRUE")))
  
#corXY.ci %>% 
#  arrange(ntraits, Trait.comb, Coef.obs) %>% 
# dplyr::select(Trait.comb, Test, n, ntraits, everything())

traits.sign.alone <- corXY.ci %>% 
  filter(ntraits==1) %>% 
  filter(sign_plus==T) %>% 
  pull(trait1)

### filter combinations where all traits belong to traits.sign.alone
mydata <- corXY.ci %>% 
  filter_at(.vars=vars(trait1:trait15), all_vars(. %in% traits.sign.alone | is.na(.)))%>% 
  mutate(seq=1:n())


### Plot combinations one by one
mydata.byone <- mydata %>% 
  filter(ntraits==1)%>% 
  mutate(seq=1:n())


top.first <- ggplot(data=mydata.byone) + 
  geom_segment(aes(x=q025, xend=q975, y=seq, yend=seq, 
                   col=sign_plus)) + 
  geom_point(aes(x=Coef.obs, y=seq), pch=15) + 
  scale_y_continuous(breaks=mydata.byone$seq, 
                     labels=mydata.byone$trait1, name=NULL)  +  
  scale_x_continuous(name="RD correlation") + 
  labs(fill = "Significant")

tt2 <- ttheme_minimal()
topfirst.leg <- cowplot::plot_grid(top.first,
                         tableGrob(trait.labs %>% 
                                     dplyr::select(trait.name), theme=tt2), 
                         nrow=1, rel_widths=c(0.65, 0.35))


ggsave(filename = "_pics/TopFirstPredictors_CI.png", dpi=400, 
       width=6, height=5, topfirst.leg)

allpredictors <- top.first %+% (mydata) +
  scale_y_continuous(breaks=mydata$seq, 
                     labels=mydata$Trait.comb) + 
  theme_classic() + 
  theme(axis.text.y = element_text(size=3)) #+ 
  #facet_wrap(.~ntraits, scales = "free_y",  nrow=2)

ggsave(filename = "_pics/All_predictors_sign_individually_CI_unfaceted.png", dpi=400, 
       width=6, height=30, allpredictors)
  


get.best <- function(x, N){
  out <- x %>% 
    filter(ntraits==N) %>% 
    filter(sign_plus==TRUE) %>% 
    arrange(desc(Coef.obs)) %>% 
    slice(1) %>% 
    pull(Trait.comb)
  lab <- trait.labs %>%
    filter(Trait.comb %in% strsplit(out, split = "_")[[1]]) %>% 
    pull(trait.name)
  return(list(Trait.comb=out, trait.name=lab))
}

top.one.by.one <- get.best(mydata, N=1)


maxtraits <- 10
for(nn in 1:maxtraits){
  if(nn==1) {
    best.at.1 <- get.best(mydata, N=nn)
    newdata <- mydata %>% 
      filter_at(.vars=vars(trait1:trait15),
                .vars_predicate = any_vars(. %in% best.at.1$trait.name | is.na(.))) 
    new.best.row <- newdata %>% 
      filter(Trait.comb==best.at.1$Trait.comb) 
    upper <- best.row$q975
    lower <- best.row$q025
    print(paste("new best at nn", nn, best.at.1$trait.name))
  }
  if(nn>1){
    better <- list()
    better$Trait.comb <- newdata %>% 
       filter(ntraits==nn) %>% 
       filter(q025>upper) %>% 
       arrange(desc(Coef.obs)) %>% 
       slice(1) %>% 
       pull(Trait.comb)

     if(length(better$Trait.comb>0)){
       better$trait.name <- trait.labs %>%
         filter(Trait.comb %in% strsplit(better$Trait.comb, split = "_")[[1]]) %>% 
         pull(trait.name)
       
       newdata <- newdata %>% 
         rowwise() %>% 
         mutate(nmatching= sum(unlist(strsplit(Trait.comb, "_")) %in% 
                                 unlist(strsplit(better$Trait.comb, "_")),
                                 na.rm=T)) %>% 
         ungroup() %>% 
         filter(nmatching==nn)
       
       new.best.row <- newdata %>% 
         filter(Trait.comb==better$Trait.comb) 
       upper <- new.best.row$q975
       lower <- new.best.row$q025
       print(paste("new best at nn", nn, paste(better$trait.name, collapse=" ")))
       best <- better
     }
  }
}

mydata.best <- mydata %>% 
  filter_at(.vars=vars(trait1:trait15), 
            .vars_predicate = all_vars(. %in% best$trait.name | is.na(.))) %>% 
  filter(ntraits <= length(best$trait.name)) %>% 
  arrange(ntraits, Coef.obs) %>% 
  mutate(seq=1:n())

(top.all <- top.first %+% mydata.best + 
    scale_y_continuous(breaks=mydata.best$seq, 
                       labels=mydata.best$Trait.comb) + 
    theme(axis.text.y = element_text(size=3)))

ggsave(filename = "_pics/Best8_AllCombinations_CI.png", dpi=400, 
       width=6, height=10, top.all)

mydata.out <- mydata %>%
  #filter(ntraits<3)%>% 
  #filter(sign_plus==T) %>% 
  #filter(trait1 %in% traits.sign.alone & (is.na(trait2) | trait2 %in% traits.sign.alone)) %>% 
  mutate(seq=1:nrow(.)) # %>% 
#  arrange(desc(obs)) %>% 
#  slice(1:20)

top10 <- ggplot(data=mydata.out %>% 
                  rename(Significant=sign_plus)) + 
  geom_segment(aes(x=q025, xend=q975, y=seq, yend=seq, 
                   col=Significant)) + 
  geom_point(aes(x=Coef.obs, y=seq), pch=15) +
  facet_wrap(.~ntraits, nrow=2, scales = "free_y") + 
  scale_y_continuous(breaks=mydata$seq, 
                     labels=mydata$Trait.comb, 
                     name="Trait combination") +  
  scale_x_continuous(name="RD correlation") + 
  theme(legend.position="bottom", legend.box = "horizontal")

#library(gridExtra)
#library(grid)
#tt2 <- ttheme_minimal()
#top7.leg <- cowplot::plot_grid(top7,
#                         tableGrob(trait.labs %>% dplyr::select(trait.name), theme=tt2), 
#                         nrow=1, rel_widths=c(0.65, 0.35))
#
#ggsave(filename = "_pics/Top07Predictors_CI.png", dpi=400, 
#       width=8, height=11, top7.leg)




#traits.sign <- traits %>% 
#  rownames_to_column("species0") %>% 
#  dplyr::select(species0, all_of(traits.sign.alone))
#write_delim(traits.sign, path="_data/Mesobromion/traits.out.10perc.sign.txt", delim="\t")

break()




#### Calculate and plot PCA of CWMs
CWM.wide <- species %>% 
  rownames_to_column("RELEVE_NR") %>% 
  reshape2::melt(.id="RELEVE_NR") %>% 
  rename(species0=variable, pres=value) %>% 
  as.tbl() %>% 
  filter(pres>0) %>% 
  arrange(RELEVE_NR)  %>% 
  ## attach traits 
  left_join(traits %>% 
              rownames_to_column("species0"), 
            by="species0") %>% 
  group_by(RELEVE_NR) %>% 
  summarize_at(.vars = vars(LEB_F_Makrophanerophyt:Disp.unit.leng), 
            .funs = list(~weighted.mean(., pres, na.rm=T))) %>%
  dplyr::select(RELEVE_NR, order(colnames(.))) %>% 
  column_to_rownames("RELEVE_NR")

#PCA of CWMs
CWM.pca <- vegan::rda(CWM.wide, scale=T)
varexpl <- round(CWM.pca$CA$eig/sum(CWM.pca$CA$eig)*100,1)

ggplot() + 
  geom_point(data=as.data.frame(CWM.pca$CA$u[,1:2]), 
             aes(x=PC1, y=PC2), pch="+", size=2, alpha=0.8) + 
  geom_segment(data=as.data.frame(CWM.pca$CA$v*2) %>% 
                 rownames_to_column("Trait") %>% 
                 mutate(in.try=ifelse(Trait %in% colnames(alltry), "Dark red", "Dark blue")), 
               aes(x=0, xend=PC1, y=0, yend=PC2, col=in.try), arrow = arrow(length = unit(0.08, "inches")), alpha=0.8) +
  geom_text(data=as.data.frame(CWM.pca$CA$v*2.1) %>% 
              rownames_to_column("Trait") %>% 
              mutate(in.try=ifelse(Trait %in% colnames(alltry), "Dark red", "Dark blue")), 
            aes(x=PC1, y=PC2, label=Trait, col=in.try),  size=3 ) +
  scale_color_identity() + 
  xlab(paste("PC1 (", varexpl[1], "%)", sep="")) + 
  ylab(paste("PC2 (", varexpl[2], "%)", sep="")) + 
  theme_bw() + 
  theme(panel.grid = element_blank()) + 
  title("PCA of CWMs")

#PCA of individual traits
trait.pca <- vegan::rda(as.matrix(traits %>% 
                                    filter(!is.na(rowSums(.)))), na.action=na.omit)
varexpl.t <- round(trait.pca$CA$eig/sum(trait.pca$CA$eig)*100,1)

ggplot() + 
  geom_point(data=as.data.frame(trait.pca$CA$u[,1:2]), 
             aes(x=PC1, y=PC2), pch="+", size=2, alpha=0.8) + 
  geom_segment(data=as.data.frame(trait.pca$CA$v*2) %>% 
                 rownames_to_column("Trait") %>% 
                 mutate(in.try=ifelse(Trait %in% colnames(alltry), "Dark red", "Dark blue")), 
               aes(x=0, xend=PC1, y=0, yend=PC2, col=in.try), arrow = arrow(length = unit(0.08, "inches")), alpha=0.8) +
  geom_text(data=as.data.frame(trait.pca$CA$v*2.1) %>% 
              rownames_to_column("Trait") %>% 
              mutate(in.try=ifelse(Trait %in% colnames(alltry), "Dark red", "Dark blue")), 
            aes(x=PC1, y=PC2, label=Trait, col=in.try),  size=3 ) +
  scale_color_identity() + 
  xlab(paste("PC1 (", varexpl[1], "%)", sep="")) + 
  ylab(paste("PC2 (", varexpl[2], "%)", sep="")) + 
  theme_bw() + 
  theme(panel.grid = element_blank()) + 
  title("PCA of species-level traits")




#### Map of plots
library(rgdal)
library(sp)
library(sf)
DE_NUTS1 <- readOGR(dsn="/data/sPlot/users/Francesco/Project_11/Germany/_data/Spatial", layer="Germany_LVL1_WGS84")
DE_NUTS_sf <- DE_NUTS1 %>% 
  st_as_sf()

env.sf <- SpatialPointsDataFrame(coords=env %>% dplyr::select(LON, LAT), 
                                 data=env %>% dplyr::select(-LON, -LAT), 
                                 proj4string = raster::crs(DE_NUTS1)) %>% 
  st_as_sf()

env.all.sf <- SpatialPointsDataFrame(coords=env.all %>% dplyr::select(LON, LAT), 
                                 data=env.all %>% dplyr::select(-LON, -LAT), 
                                 proj4string = raster::crs(DE_NUTS1)) %>% 
  st_as_sf()


(basemap2 <- ggplot(data=DE_NUTS_sf) + 
  geom_sf(col="darkgrey", lwd=0.5, fill="white", alpha=0.5)+
  geom_sf(data=env.all.sf, col=gray(0.5), size=1) + 
  geom_sf(data=env.sf, col="red", alpha=0.5, size=1) + 
  #geom_polygon(col="darkgrey", lwd=0.5, fill="white")+
  coord_sf() + 
  theme_bw()
)

ggsave(filename="_data/Mesobromion/PlotDistribution.png", height=8, width=6, dpi=300, basemap2)



## Graph of PCoA + passive projection of CWM
library(vegan)
fuzzy <- read.table("_data/Mesobromion/X_Dry-Grassland_581plots_488spp_R.txt", header=T)#, delim="\t")
cwms <- read.table("_data/Mesobromion/X_scores_T_Dry-Grassland_581plots_5traits_Rao_R.txt", header=T) %>% 
  dplyr::select(-Axis1, -Axis2)   #, delim="\t")
  
pcoa.out <- wcmdscale(dist(fuzzy), eig=T)
varexpl <- round((pcoa.out$eig)/sum(pcoa.out$eig)*100,1)
cwms.envfit <- envfit(pcoa.out, cwms)


plot(pcoa.out, type = "p")
plot(cwms.envfit)

ggplot() + 
  geom_point(data=as.data.frame(pcoa.out$points[,1:2]), 
             aes(x=Dim1, y=Dim2), pch="+", size=2, alpha=0.8) + 
  geom_segment(data=as.data.frame(cwms.envfit$vectors$arrows*.0008), 
               aes(x=0, xend=Dim1, y=0, yend=Dim2), col="Dark blue", arrow = arrow(length = unit(0.08, "inches")), alpha=0.8) +
  geom_text(data=as.data.frame(cwms.envfit$vectors$arrows*.00092) %>% 
               rownames_to_column("Trait"), 
               aes(x=Dim1, y=Dim2, label=Trait), col="Dark blue", size=3 ) +
  xlab(paste("PCoA1 (", varexpl[1], "%)", sep="")) + 
  ylab(paste("PCoA2 (", varexpl[2], "%)", sep="")) + 
  theme_bw() + 
  theme(panel.grid = element_blank())

ggsave("_data/Mesobromion/PCoA_traits.png", width=6, height=4, dpi=300, last_plot())





