#Functions to define correlations between Beals, SYNCSA, ENV
# W - Sp. composition
# X - fuzzy weighted
# Y - Beals
# B - traits
# E - Environment


require(tidyverse)
require(SYNCSA)
require(vegan)
require(abind)
require(ade4)
require(parallel)
require(doParallel)


source("99_HIDDEN_functions.R")


Mesobromion <- function(species.path, traits.path, output, myfunction="get.corXY.bootstrap
", max.inter.t, chunkn, chunk.i, nperm=199){

  myfunction <- get(myfunction)
  ## calculate corr between species composition matrix and traits
  species <- read_delim(species.path, delim="\t") %>%
		as.data.frame()
  traits <- read_delim(traits.path, delim="\t") %>%
		as.data.frame()
  
  
  traits <- traits %>% 
    column_to_rownames("species0") %>% 
    rename_all(.funs=~gsub(pattern=".mean$", replacement="", x=.))  #%>% 
#temporary    ### Use only a subset of traits
    #dplyr::select(LeafArea:Disp.unit.leng)
  
  ## create list of indices for each combination of traits up to a max number of interactions
  n.traits <- ncol(traits)
  allcomb.t <- NULL
  for(n.inter in 1:max.inter.t){
    allcomb.t <- c(allcomb.t, combn(1:n.traits, n.inter, simplify=F))
  }
  nall <- length(allcomb.t)
  
  ## Divide in chunks if requested
  if(chunkn>1 & !is.na(chunk.i)){
      print(paste("divide in", chunkn, "chunks and run on chunk n.", chunk.i))
      indices <- 1:length(allcomb.t)
      chunks <- split(indices, sort(indices%%chunkn))
      allcomb.t <- allcomb.t[chunks[[chunk.i]]]
    } 
  print(paste("Running on", length(allcomb.t),"out of", nall, "combinations"))
  names.t <- unlist(lapply(allcomb.t, paste, collapse="_"))
  
  print("Start main loop")
#  cor.obs <- NA
#  cor.bootstr <- matrix(NA, nrow=length(allcomb.t), ncol=nperm, 
#                        dimnames = list(paste("t", names.t, sep=""), paste("p",1:nperm, sep="")))
#  cor.perm <- matrix(NA, nrow=length(allcomb.t), ncol=nperm, 
#                     dimnames = list(paste("t", names.t, sep=""), paste("p",1:nperm, sep="")))
                                                                             
  corXY.output <- NULL
  for(i in 1:length(allcomb.t)) {
    tt <- unlist(allcomb.t[i])
    #bootstrap species matrix 
#    set.seed(1984)
    corXY.output <- rbind(corXY.output, 
                          get.corXY.bootstrap(comm=species, trait=traits, 
                                              trait.sel=tt, bootstrap=nperm))
    save(corXY.output, file = paste(output, "_", chunk.i, ".RData", sep=""))
  }
}
